Module csl

Module csl 

CSL (Compressed Sparse Line).

A generalization of the CSC/CSR structures for N dimensions. Beware that this structure doesn’t make any distinction of what is a column or a row because the order of the elements is up to the caller.

Structs

Csl
Base structure for all CSL* variants.
CslLineConstructor
Constructs valid lines in a easy and interactive manner, abstracting away the complexity of the compressed sparse format.
CslLineIterMut
Iterator of a CSL dimension.
CslLineIterRef
Iterator of a CSL dimension.

Enums

CslError
Any error related to Csl operations
CslLineConstructorError
Contains all errors related to CslLineConstructor.

Type Aliases

CslArray
CSL backed by a static array.
CslMut
CSL backed by a mutable slice
CslRef
CSL backed by a slice
CslVec
CSL backed by a dynamic vector.