Module doc_tests

Module doc_tests 

Instances for documentation tests or tests.

Functions

coo_array_5
As odd as it may seem, this illustration is just a guide to get a grasp of a 5D structure.
coo_vec_5
alloc::vec::Vec version of coo_array_5.
csl_array_4
Two cuboids illustrating a [2, 3, 4, 5] 4D in a [w, y, z, x] order, i.e., each “line” or 1D representation is a left to right row and each “matrix” or 2D representation is filled in a top-down manner.
csl_vec_4
alloc::vec::Vec version of csl_array_4.
dense_array_3
A dense cube, i.e., a fully filled cube.