Structs
- Csl
- Base structure for all CSL* variants.
- CslLine
Constructor - Constructs valid lines in a easy and interactive manner, abstracting away the complexity of the compressed sparse format.
- CslLine
Iter Mut - Iterator of a CSL dimension.
- CslLine
Iter Ref - Iterator of a CSL dimension.
Enums
- CslError
- Any error related to Csl operations
- CslLine
Constructor Error - Contains all errors related to
CslLineConstructor.