Instances for documentation tests or tests.
Functions
- coo_
array_ 5 - As odd as it may seem, this illustration is just a guide to get a grasp of a 5D structure.
- coo_
vec_ 5 alloc::vec::Vecversion ofcoo_array_5.- csl_
array_ 4 - Two cuboids illustrating a [2, 3, 4, 5] 4D in a [w, y, z, x] order, i.e., each “line” or 1D representation is a left to right row and each “matrix” or 2D representation is filled in a top-down manner.
- csl_
vec_ 4 alloc::vec::Vecversion ofcsl_array_4.- dense_
array_ 3 - A dense cube, i.e., a fully filled cube.